===================
Configuration Guide
===================

.. toctree::
   :maxdepth: 1

   skyline-console-settings

For more information about skyline configuration settings, see
`OpenStack Skyline Settings <https://docs.openstack.org/skyline-apiserver/latest/configuration/settings.html>`__.
